@@ -77,7 +77,7 @@ setMethod(
 .bc_cplx_math <- function(x, y, op, abortcall) {
   
   if(length(x) == 0L || length(y) == 0L) {
-    return(complex(0L))
+    return(.binary_return_zerolen(x, y, FALSE, "complex"))
   }
   
   prep <- .binary_prep(x, y, abortcall)
@@ -127,7 +127,7 @@ setMethod(
   
   
   if(length(x) == 0L || length(y) == 0L) {
-    return(logical(0L))
+    return(.binary_return_zerolen(x, y, TRUE, "logical"))
   }
   
   prep <- .binary_prep(x, y, abortcall)
@@ -164,7 +164,7 @@ setMethod(
   
   .rcpp_set_attr(out, "dim", out.dimorig)
   
-  .binary_set_attr(out, x, y)
+  .binary_set_attr_logical(out, x, y)
   
   return(out)
   
