@@ -10,7 +10,7 @@ using namespace Rcpp;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bcRel_str_v)]]
+// [[Rcpp::export(.rcpp_bcRel_str_v, rng = false)]]
 SEXP rcpp_bcRel_str_v(
   SEXP x, SEXP y,
   R_xlen_t nout, int op
@@ -39,7 +39,7 @@ return out;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bcRel_str_ov)]]
+// [[Rcpp::export(.rcpp_bcRel_str_ov, rng = false)]]
 SEXP rcpp_bcRel_str_ov(
   SEXP x, SEXP y, bool RxC, SEXP out_dim,
   R_xlen_t nout, int op
@@ -67,7 +67,35 @@ return out;
 
 //' @keywords internal
 //' @noRd
-// [[Rcpp::export(.rcpp_bcRel_str_d)]]
+// [[Rcpp::export(.rcpp_bcRel_str_bv, rng = false)]]
+SEXP rcpp_bcRel_str_bv(
+  SEXP x, SEXP y, bool bigx, SEXP out_dim,
+  R_xlen_t nout, int op
+) {
+
+
+int tempout;
+
+const SEXP *px = STRING_PTR_RO(x);
+const SEXP *py = STRING_PTR_RO(y);
+
+SEXP out = PROTECT(Rf_allocVector(LGLSXP, nout));
+int *pout;
+pout = LOGICAL(out);
+
+MACRO_OP_STR_REL(MACRO_DIM_BIG2VECTOR);
+
+UNPROTECT(1);
+return out;
+
+}
+
+
+
+
+//' @keywords internal
+//' @noRd
+// [[Rcpp::export(.rcpp_bcRel_str_d, rng = false)]]
 SEXP rcpp_bcRel_str_d(
   SEXP x, SEXP y,
   SEXP by_x,
